"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from delphix.api.gateway.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
)
from ..model_utils import OpenApiModel
from delphix.api.gateway.exceptions import ApiAttributeError



class TimestampCompatibleRepositoryRequest(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
    }

    validations = {
        ('source_data_id',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('engine_id',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('timeflow_id',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('environment_id',): {
            'max_length': 256,
            'min_length': 1,
        },
    }

    @cached_property
    def additional_properties_type():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded
        """
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        return {
            'source_data_id': (str,),  # noqa: E501
            'engine_id': (str,),  # noqa: E501
            'timestamp': (datetime,),  # noqa: E501
            'timeflow_id': (str,),  # noqa: E501
            'environment_id': (str,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'source_data_id': 'source_data_id',  # noqa: E501
        'engine_id': 'engine_id',  # noqa: E501
        'timestamp': 'timestamp',  # noqa: E501
        'timeflow_id': 'timeflow_id',  # noqa: E501
        'environment_id': 'environment_id',  # noqa: E501
    }

    read_only_vars = {
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, *args, **kwargs):  # noqa: E501
        """TimestampCompatibleRepositoryRequest - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            source_data_id (str): The ID of the source object (dSource or VDB) to get the compatible repos. All other objects referenced by the parameters must live on the same engine as the source.. [optional]  # noqa: E501
            engine_id (str): The ID of the Engine from where to get the compatible repos. If the source ID unambiguously identifies a source object, this parameter is unnecessary and ignored.. [optional]  # noqa: E501
            timestamp (datetime): The point in time from which to execute the operation. If the timestamp is not set, selects the latest point.. [optional]  # noqa: E501
            timeflow_id (str): ID of the timeflow from which compatible repos need to be fetched, mutually exclusive with source_data_id.. [optional]  # noqa: E501
            environment_id (str): The ID or name of the target environment.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(OpenApiModel, cls).__new__(cls)

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, *args, **kwargs):  # noqa: E501
        """TimestampCompatibleRepositoryRequest - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            source_data_id (str): The ID of the source object (dSource or VDB) to get the compatible repos. All other objects referenced by the parameters must live on the same engine as the source.. [optional]  # noqa: E501
            engine_id (str): The ID of the Engine from where to get the compatible repos. If the source ID unambiguously identifies a source object, this parameter is unnecessary and ignored.. [optional]  # noqa: E501
            timestamp (datetime): The point in time from which to execute the operation. If the timestamp is not set, selects the latest point.. [optional]  # noqa: E501
            timeflow_id (str): ID of the timeflow from which compatible repos need to be fetched, mutually exclusive with source_data_id.. [optional]  # noqa: E501
            environment_id (str): The ID or name of the target environment.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_openapi_data` to instantiate "
                                     f"class with read only attributes.")



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.delete_d_source_response_all_of import DeleteDSourceResponseAllOf
from delphix.api.gateway.model.engine import Engine
from delphix.api.gateway.model.job import Job
from delphix.api.gateway.model.job_task import JobTask
from delphix.api.gateway.model.tag import Tag
from delphix.api.gateway.model.virtualization_task import VirtualizationTask
globals()['DeleteDSourceResponseAllOf'] = DeleteDSourceResponseAllOf
globals()['Engine'] = Engine
globals()['Job'] = Job
globals()['JobTask'] = JobTask
globals()['Tag'] = Tag
globals()['VirtualizationTask'] = VirtualizationTask
from delphix.api.gateway.model.delete_d_source_response import DeleteDSourceResponse


class TestDeleteDSourceResponse(unittest.TestCase):
    """DeleteDSourceResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDeleteDSourceResponse(self):
        """Test DeleteDSourceResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = DeleteDSourceResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.data_risk_data import DataRiskData
from delphix.api.gateway.model.data_risk_report_totals import DataRiskReportTotals
from delphix.api.gateway.model.paginated_response_metadata import PaginatedResponseMetadata
globals()['DataRiskData'] = DataRiskData
globals()['DataRiskReportTotals'] = DataRiskReportTotals
globals()['PaginatedResponseMetadata'] = PaginatedResponseMetadata
from delphix.api.gateway.model.search_data_risk_report_response import SearchDataRiskReportResponse


class TestSearchDataRiskReportResponse(unittest.TestCase):
    """SearchDataRiskReportResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSearchDataRiskReportResponse(self):
        """Test SearchDataRiskReportResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SearchDataRiskReportResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from delphix.api.gateway.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
)
from ..model_utils import OpenApiModel
from delphix.api.gateway.exceptions import ApiAttributeError


def lazy_import():
    from delphix.api.gateway.model.environment_repository_all_of import EnvironmentRepositoryAllOf
    from delphix.api.gateway.model.mssql_cluster_listener import MSSQLClusterListener
    from delphix.api.gateway.model.repository import Repository
    globals()['EnvironmentRepositoryAllOf'] = EnvironmentRepositoryAllOf
    globals()['MSSQLClusterListener'] = MSSQLClusterListener
    globals()['Repository'] = Repository


class EnvironmentRepository(ModelComposed):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
    }

    validations = {
    }

    @cached_property
    def additional_properties_type():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded
        """
        lazy_import()
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'id': (str,),  # noqa: E501
            'name': (str,),  # noqa: E501
            'database_type': (str,),  # noqa: E501
            'allow_provisioning': (bool,),  # noqa: E501
            'is_staging': (bool,),  # noqa: E501
            'oracle_base': (str,),  # noqa: E501
            'version': (str,),  # noqa: E501
            'bits': (int,),  # noqa: E501
            'install_group': (str,),  # noqa: E501
            'install_user': (str,),  # noqa: E501
            'rac': (bool,),  # noqa: E501
            'ports': ([int],),  # noqa: E501
            'port': (int,),  # noqa: E501
            'dump_history_file': (str,),  # noqa: E501
            'page_size': (int,),  # noqa: E501
            'owner': (str,),  # noqa: E501
            'installation_path': (str,),  # noqa: E501
            'fulltext_installed': (bool,),  # noqa: E501
            'internal_version': (int,),  # noqa: E501
            'mssql_cluster_instances_name': ([str],),  # noqa: E501
            'mssql_cluster_instances_version': ([str],),  # noqa: E501
            'mssql_cluster_instances_owners': ([str],),  # noqa: E501
            'mssql_cluster_instances_ports': ([int],),  # noqa: E501
            'mssql_cluster_instances_server_names': ([str],),  # noqa: E501
            'mssql_cluster_instances_nodes': ([str],),  # noqa: E501
            'installation_home': (str,),  # noqa: E501
            'drive_letter': ([str],),  # noqa: E501
            'discovered': (bool,),  # noqa: E501
            'mssql_listeners': ([MSSQLClusterListener],),  # noqa: E501
            'database_username': (str,),  # noqa: E501
            'service_principal_name': (str,),  # noqa: E501
            'isql_path': (str,),  # noqa: E501
            'ase_tls_enabled': (bool,),  # noqa: E501
            'environment_id': (str,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'id': 'id',  # noqa: E501
        'name': 'name',  # noqa: E501
        'database_type': 'database_type',  # noqa: E501
        'allow_provisioning': 'allow_provisioning',  # noqa: E501
        'is_staging': 'is_staging',  # noqa: E501
        'oracle_base': 'oracle_base',  # noqa: E501
        'version': 'version',  # noqa: E501
        'bits': 'bits',  # noqa: E501
        'install_group': 'install_group',  # noqa: E501
        'install_user': 'install_user',  # noqa: E501
        'rac': 'rac',  # noqa: E501
        'ports': 'ports',  # noqa: E501
        'port': 'port',  # noqa: E501
        'dump_history_file': 'dump_history_file',  # noqa: E501
        'page_size': 'page_size',  # noqa: E501
        'owner': 'owner',  # noqa: E501
        'installation_path': 'installation_path',  # noqa: E501
        'fulltext_installed': 'fulltext_installed',  # noqa: E501
        'internal_version': 'internal_version',  # noqa: E501
        'mssql_cluster_instances_name': 'mssql_cluster_instances_name',  # noqa: E501
        'mssql_cluster_instances_version': 'mssql_cluster_instances_version',  # noqa: E501
        'mssql_cluster_instances_owners': 'mssql_cluster_instances_owners',  # noqa: E501
        'mssql_cluster_instances_ports': 'mssql_cluster_instances_ports',  # noqa: E501
        'mssql_cluster_instances_server_names': 'mssql_cluster_instances_server_names',  # noqa: E501
        'mssql_cluster_instances_nodes': 'mssql_cluster_instances_nodes',  # noqa: E501
        'installation_home': 'installation_home',  # noqa: E501
        'drive_letter': 'drive_letter',  # noqa: E501
        'discovered': 'discovered',  # noqa: E501
        'mssql_listeners': 'mssql_listeners',  # noqa: E501
        'database_username': 'database_username',  # noqa: E501
        'service_principal_name': 'service_principal_name',  # noqa: E501
        'isql_path': 'isql_path',  # noqa: E501
        'ase_tls_enabled': 'ase_tls_enabled',  # noqa: E501
        'environment_id': 'environment_id',  # noqa: E501
    }

    read_only_vars = {
        'discovered',  # noqa: E501
    }

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, *args, **kwargs):  # noqa: E501
        """EnvironmentRepository - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            id (str): Entity id of the repository.. [optional]  # noqa: E501
            name (str): Name of the repository.. [optional]  # noqa: E501
            database_type (str): The database type of this repository.. [optional]  # noqa: E501
            allow_provisioning (bool): Flag indicating whether the repository should be used for provisioning.. [optional]  # noqa: E501
            is_staging (bool): Flag indicating whether this repository can be used by the Delphix Engine for internal processing.. [optional]  # noqa: E501
            oracle_base (str): The Oracle base where database binaries are located.. [optional]  # noqa: E501
            version (str): Version of the repository.. [optional]  # noqa: E501
            bits (int): 32 or 64 bits.. [optional]  # noqa: E501
            install_group (str): Group name of the user that owns the install.. [optional]  # noqa: E501
            install_user (str): User name of the user that owns the install.. [optional]  # noqa: E501
            rac (bool): Flag indicating whether the install supports Oracle RAC.. [optional]  # noqa: E501
            ports ([int]): The network ports for connecting to the database instance.. [optional]  # noqa: E501
            port (int): The network port for connecting to the SQL Server instance.. [optional]  # noqa: E501
            dump_history_file (str): Fully qualified name of the dump history file.. [optional]  # noqa: E501
            page_size (int): Database page size for the SAP ASE instance.. [optional]  # noqa: E501
            owner (str): Account the database server instance is running as.. [optional]  # noqa: E501
            installation_path (str): Directory path where the installation is located.. [optional]  # noqa: E501
            fulltext_installed (bool): This property determines if the full-text search and semantic search is installed or not.. [optional]  # noqa: E501
            internal_version (int): The internal version is tied to the data format of a database and is used to detect compatibility.. [optional]  # noqa: E501
            mssql_cluster_instances_name ([str]): MSSQL cluster instances name.. [optional]  # noqa: E501
            mssql_cluster_instances_version ([str]): MSSQL cluster instances version.. [optional]  # noqa: E501
            mssql_cluster_instances_owners ([str]): MSSQL cluster instance owners.. [optional]  # noqa: E501
            mssql_cluster_instances_ports ([int]): MSSQL cluster instances ports.. [optional]  # noqa: E501
            mssql_cluster_instances_server_names ([str]): MSSQL cluster instances server names.. [optional]  # noqa: E501
            mssql_cluster_instances_nodes ([str]): MSSQL cluster instances nodes.. [optional]  # noqa: E501
            installation_home (str): Directory where the installation home is located.. [optional]  # noqa: E501
            drive_letter ([str]): MSSQL failover cluster drive letter.. [optional]  # noqa: E501
            discovered (bool): Flag indicating whether the repository was automatically discovered.. [optional]  # noqa: E501
            mssql_listeners ([MSSQLClusterListener]): The list of listeners belonging to this repository.. [optional]  # noqa: E501
            database_username (str): The username of the ASE instance database.. [optional]  # noqa: E501
            service_principal_name (str): The Kerberos Service Principal Name (SPN) of the database.. [optional]  # noqa: E501
            isql_path (str): The path to the isql binary to use for this SAP ASE instance.. [optional]  # noqa: E501
            ase_tls_enabled (bool): True if SAP ASE instance is TLS/SSL enabled.. [optional]  # noqa: E501
            environment_id (str): The environment ID.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(OpenApiModel, cls).__new__(cls)

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        constant_args = {
            '_check_type': _check_type,
            '_path_to_item': _path_to_item,
            '_spec_property_naming': _spec_property_naming,
            '_configuration': _configuration,
            '_visited_composed_classes': self._visited_composed_classes,
        }
        composed_info = validate_get_composed_info(
            constant_args, kwargs, self)
        self._composed_instances = composed_info[0]
        self._var_name_to_model_instances = composed_info[1]
        self._additional_properties_model_instances = composed_info[2]
        discarded_args = composed_info[3]

        for var_name, var_value in kwargs.items():
            if var_name in discarded_args and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self._additional_properties_model_instances:
                # discard variable.
                continue
            setattr(self, var_name, var_value)

        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
        '_composed_instances',
        '_var_name_to_model_instances',
        '_additional_properties_model_instances',
    ])

    @convert_js_args_to_python_args
    def __init__(self, *args, **kwargs):  # noqa: E501
        """EnvironmentRepository - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            id (str): Entity id of the repository.. [optional]  # noqa: E501
            name (str): Name of the repository.. [optional]  # noqa: E501
            database_type (str): The database type of this repository.. [optional]  # noqa: E501
            allow_provisioning (bool): Flag indicating whether the repository should be used for provisioning.. [optional]  # noqa: E501
            is_staging (bool): Flag indicating whether this repository can be used by the Delphix Engine for internal processing.. [optional]  # noqa: E501
            oracle_base (str): The Oracle base where database binaries are located.. [optional]  # noqa: E501
            version (str): Version of the repository.. [optional]  # noqa: E501
            bits (int): 32 or 64 bits.. [optional]  # noqa: E501
            install_group (str): Group name of the user that owns the install.. [optional]  # noqa: E501
            install_user (str): User name of the user that owns the install.. [optional]  # noqa: E501
            rac (bool): Flag indicating whether the install supports Oracle RAC.. [optional]  # noqa: E501
            ports ([int]): The network ports for connecting to the database instance.. [optional]  # noqa: E501
            port (int): The network port for connecting to the SQL Server instance.. [optional]  # noqa: E501
            dump_history_file (str): Fully qualified name of the dump history file.. [optional]  # noqa: E501
            page_size (int): Database page size for the SAP ASE instance.. [optional]  # noqa: E501
            owner (str): Account the database server instance is running as.. [optional]  # noqa: E501
            installation_path (str): Directory path where the installation is located.. [optional]  # noqa: E501
            fulltext_installed (bool): This property determines if the full-text search and semantic search is installed or not.. [optional]  # noqa: E501
            internal_version (int): The internal version is tied to the data format of a database and is used to detect compatibility.. [optional]  # noqa: E501
            mssql_cluster_instances_name ([str]): MSSQL cluster instances name.. [optional]  # noqa: E501
            mssql_cluster_instances_version ([str]): MSSQL cluster instances version.. [optional]  # noqa: E501
            mssql_cluster_instances_owners ([str]): MSSQL cluster instance owners.. [optional]  # noqa: E501
            mssql_cluster_instances_ports ([int]): MSSQL cluster instances ports.. [optional]  # noqa: E501
            mssql_cluster_instances_server_names ([str]): MSSQL cluster instances server names.. [optional]  # noqa: E501
            mssql_cluster_instances_nodes ([str]): MSSQL cluster instances nodes.. [optional]  # noqa: E501
            installation_home (str): Directory where the installation home is located.. [optional]  # noqa: E501
            drive_letter ([str]): MSSQL failover cluster drive letter.. [optional]  # noqa: E501
            discovered (bool): Flag indicating whether the repository was automatically discovered.. [optional]  # noqa: E501
            mssql_listeners ([MSSQLClusterListener]): The list of listeners belonging to this repository.. [optional]  # noqa: E501
            database_username (str): The username of the ASE instance database.. [optional]  # noqa: E501
            service_principal_name (str): The Kerberos Service Principal Name (SPN) of the database.. [optional]  # noqa: E501
            isql_path (str): The path to the isql binary to use for this SAP ASE instance.. [optional]  # noqa: E501
            ase_tls_enabled (bool): True if SAP ASE instance is TLS/SSL enabled.. [optional]  # noqa: E501
            environment_id (str): The environment ID.. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        constant_args = {
            '_check_type': _check_type,
            '_path_to_item': _path_to_item,
            '_spec_property_naming': _spec_property_naming,
            '_configuration': _configuration,
            '_visited_composed_classes': self._visited_composed_classes,
        }
        composed_info = validate_get_composed_info(
            constant_args, kwargs, self)
        self._composed_instances = composed_info[0]
        self._var_name_to_model_instances = composed_info[1]
        self._additional_properties_model_instances = composed_info[2]
        discarded_args = composed_info[3]

        for var_name, var_value in kwargs.items():
            if var_name in discarded_args and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self._additional_properties_model_instances:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_openapi_data` to instantiate "
                                     f"class with read only attributes.")

    @cached_property
    def _composed_schemas():
        # we need this here to make our import statements work
        # we must store _composed_schemas in here so the code is only run
        # when we invoke this method. If we kept this at the class
        # level we would get an error beause the class level
        # code would be run when this module is imported, and these composed
        # classes don't exist yet because their module has not finished
        # loading
        lazy_import()
        return {
          'anyOf': [
          ],
          'allOf': [
              EnvironmentRepositoryAllOf,
              Repository,
          ],
          'oneOf': [
          ],
        }



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.oracle_virtual_ip import OracleVirtualIP
from delphix.api.gateway.model.ssh_verification_strategy import SSHVerificationStrategy
globals()['OracleVirtualIP'] = OracleVirtualIP
globals()['SSHVerificationStrategy'] = SSHVerificationStrategy
from delphix.api.gateway.model.host_update_parameters import HostUpdateParameters


class TestHostUpdateParameters(unittest.TestCase):
    """HostUpdateParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testHostUpdateParameters(self):
        """Test HostUpdateParameters"""
        # FIXME: construct object with mandatory attributes with example values
        # model = HostUpdateParameters()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.algorithms_api import AlgorithmsApi  # noqa: E501


class TestAlgorithmsApi(unittest.TestCase):
    """AlgorithmsApi unit test stubs"""

    def setUp(self):
        self.api = AlgorithmsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_algorithm_tags(self):
        """Test case for create_algorithm_tags

        Create tags for an Algorithm.  # noqa: E501
        """
        pass

    def test_delete_algorithm_tags(self):
        """Test case for delete_algorithm_tags

        Delete tags for an Algorithm.  # noqa: E501
        """
        pass

    def test_get_algorithm_by_id(self):
        """Test case for get_algorithm_by_id

        Get an algorithm by ID.  # noqa: E501
        """
        pass

    def test_get_algorithm_dependencies_by_id(self):
        """Test case for get_algorithm_dependencies_by_id

        Get dependencies of an algorithm by ID.  # noqa: E501
        """
        pass

    def test_get_algorithm_tags(self):
        """Test case for get_algorithm_tags

        Get tags for an Algorithm.  # noqa: E501
        """
        pass

    def test_get_algorithms(self):
        """Test case for get_algorithms

        Retrieve the list of algorithms.  # noqa: E501
        """
        pass

    def test_search_algorithm_dependencies(self):
        """Test case for search_algorithm_dependencies

        Search for algorithm dependencies.  # noqa: E501
        """
        pass

    def test_search_algorithms(self):
        """Test case for search_algorithms

        Search for algorithms.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from delphix.api.gateway.api_client import ApiClient, Endpoint as _Endpoint
from delphix.api.gateway.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from delphix.api.gateway.model.app_data_source_create_parameters import AppDataSourceCreateParameters
from delphix.api.gateway.model.app_data_source_update_parameters import AppDataSourceUpdateParameters
from delphix.api.gateway.model.ase_source_create_parameters import AseSourceCreateParameters
from delphix.api.gateway.model.ase_source_update_parameters import AseSourceUpdateParameters
from delphix.api.gateway.model.connectivity_check_response import ConnectivityCheckResponse
from delphix.api.gateway.model.create_app_data_source_response import CreateAppDataSourceResponse
from delphix.api.gateway.model.create_ase_source_response import CreateAseSourceResponse
from delphix.api.gateway.model.create_oracle_source_response import CreateOracleSourceResponse
from delphix.api.gateway.model.create_postgres_source_response import CreatePostgresSourceResponse
from delphix.api.gateway.model.delete_source_response import DeleteSourceResponse
from delphix.api.gateway.model.delete_tag import DeleteTag
from delphix.api.gateway.model.list_sources_response import ListSourcesResponse
from delphix.api.gateway.model.oracle_source_create_parameters import OracleSourceCreateParameters
from delphix.api.gateway.model.oracle_source_update_parameters import OracleSourceUpdateParameters
from delphix.api.gateway.model.oracle_verify_jdbc_connection_string_params import OracleVerifyJdbcConnectionStringParams
from delphix.api.gateway.model.postgres_source_create_parameters import PostgresSourceCreateParameters
from delphix.api.gateway.model.postgres_source_update_parameters import PostgresSourceUpdateParameters
from delphix.api.gateway.model.search_body import SearchBody
from delphix.api.gateway.model.search_sources_response import SearchSourcesResponse
from delphix.api.gateway.model.source import Source
from delphix.api.gateway.model.staging_compatible_environments_response import StagingCompatibleEnvironmentsResponse
from delphix.api.gateway.model.tags_request import TagsRequest
from delphix.api.gateway.model.tags_response import TagsResponse
from delphix.api.gateway.model.update_app_data_source_response import UpdateAppDataSourceResponse
from delphix.api.gateway.model.update_ase_source_response import UpdateAseSourceResponse
from delphix.api.gateway.model.update_oracle_source_response import UpdateOracleSourceResponse
from delphix.api.gateway.model.update_postgres_source_response import UpdatePostgresSourceResponse
from delphix.api.gateway.model.update_source_parameters import UpdateSourceParameters
from delphix.api.gateway.model.update_source_response import UpdateSourceResponse


class SourcesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __create_app_data_source(
            self,
            app_data_source_create_parameters,
            **kwargs
        ):
            """Create an AppData source.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.create_app_data_source(app_data_source_create_parameters, async_req=True)
            >>> result = thread.get()

            Args:
                app_data_source_create_parameters (AppDataSourceCreateParameters): The parameters to create a AppData source.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                CreateAppDataSourceResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['app_data_source_create_parameters'] = \
                app_data_source_create_parameters
            return self.call_with_http_info(**kwargs)

        self.create_app_data_source = _Endpoint(
            settings={
                'response_type': (CreateAppDataSourceResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/sources/appdata',
                'operation_id': 'create_app_data_source',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'app_data_source_create_parameters',
                ],
                'required': [
                    'app_data_source_create_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'app_data_source_create_parameters':
                        (AppDataSourceCreateParameters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'app_data_source_create_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__create_app_data_source
        )

        def __create_ase_source(
            self,
            ase_source_create_parameters,
            **kwargs
        ):
            """Create an ASE source.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.create_ase_source(ase_source_create_parameters, async_req=True)
            >>> result = thread.get()

            Args:
                ase_source_create_parameters (AseSourceCreateParameters): The parameters to create an ASE source.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                CreateAseSourceResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['ase_source_create_parameters'] = \
                ase_source_create_parameters
            return self.call_with_http_info(**kwargs)

        self.create_ase_source = _Endpoint(
            settings={
                'response_type': (CreateAseSourceResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/sources/ase',
                'operation_id': 'create_ase_source',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'ase_source_create_parameters',
                ],
                'required': [
                    'ase_source_create_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'ase_source_create_parameters':
                        (AseSourceCreateParameters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'ase_source_create_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__create_ase_source
        )

        def __create_oracle_source(
            self,
            **kwargs
        ):
            """Create an Oracle Source.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.create_oracle_source(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                oracle_source_create_parameters (OracleSourceCreateParameters): The parameters to create an Oracle source.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                CreateOracleSourceResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.create_oracle_source = _Endpoint(
            settings={
                'response_type': (CreateOracleSourceResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/sources/oracle',
                'operation_id': 'create_oracle_source',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'oracle_source_create_parameters',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'oracle_source_create_parameters':
                        (OracleSourceCreateParameters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'oracle_source_create_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__create_oracle_source
        )

        def __create_postgres_source(
            self,
            postgres_source_create_parameters,
            **kwargs
        ):
            """Create a PostgreSQL source.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.create_postgres_source(postgres_source_create_parameters, async_req=True)
            >>> result = thread.get()

            Args:
                postgres_source_create_parameters (PostgresSourceCreateParameters): The parameters to create a PostgreSQL source.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                CreatePostgresSourceResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['postgres_source_create_parameters'] = \
                postgres_source_create_parameters
            return self.call_with_http_info(**kwargs)

        self.create_postgres_source = _Endpoint(
            settings={
                'response_type': (CreatePostgresSourceResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/sources/postgres',
                'operation_id': 'create_postgres_source',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'postgres_source_create_parameters',
                ],
                'required': [
                    'postgres_source_create_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'postgres_source_create_parameters':
                        (PostgresSourceCreateParameters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'postgres_source_create_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__create_postgres_source
        )

        def __create_source_tags(
            self,
            source_id,
            tags_request,
            **kwargs
        ):
            """Create tags for a Source.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.create_source_tags(source_id, tags_request, async_req=True)
            >>> result = thread.get()

            Args:
                source_id (str): The ID of the Source.
                tags_request (TagsRequest): Tags information for Source.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                TagsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['source_id'] = \
                source_id
            kwargs['tags_request'] = \
                tags_request
            return self.call_with_http_info(**kwargs)

        self.create_source_tags = _Endpoint(
            settings={
                'response_type': (TagsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/sources/{sourceId}/tags',
                'operation_id': 'create_source_tags',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'source_id',
                    'tags_request',
                ],
                'required': [
                    'source_id',
                    'tags_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'source_id',
                ]
            },
            root_map={
                'validations': {
                    ('source_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'source_id':
                        (str,),
                    'tags_request':
                        (TagsRequest,),
                },
                'attribute_map': {
                    'source_id': 'sourceId',
                },
                'location_map': {
                    'source_id': 'path',
                    'tags_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__create_source_tags
        )

        def __delete_source(
            self,
            source_id,
            **kwargs
        ):
            """Delete a source by ID.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_source(source_id, async_req=True)
            >>> result = thread.get()

            Args:
                source_id (str): The ID of the Source.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                DeleteSourceResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['source_id'] = \
                source_id
            return self.call_with_http_info(**kwargs)

        self.delete_source = _Endpoint(
            settings={
                'response_type': (DeleteSourceResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/sources/{sourceId}',
                'operation_id': 'delete_source',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'source_id',
                ],
                'required': [
                    'source_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'source_id',
                ]
            },
            root_map={
                'validations': {
                    ('source_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'source_id':
                        (str,),
                },
                'attribute_map': {
                    'source_id': 'sourceId',
                },
                'location_map': {
                    'source_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__delete_source
        )

        def __delete_source_tags(
            self,
            source_id,
            **kwargs
        ):
            """Delete tags for a Source.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_source_tags(source_id, async_req=True)
            >>> result = thread.get()

            Args:
                source_id (str): The ID of the Source.

            Keyword Args:
                delete_tag (DeleteTag): The parameters to delete tags. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                None
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['source_id'] = \
                source_id
            return self.call_with_http_info(**kwargs)

        self.delete_source_tags = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/sources/{sourceId}/tags/delete',
                'operation_id': 'delete_source_tags',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'source_id',
                    'delete_tag',
                ],
                'required': [
                    'source_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'source_id',
                ]
            },
            root_map={
                'validations': {
                    ('source_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'source_id':
                        (str,),
                    'delete_tag':
                        (DeleteTag,),
                },
                'attribute_map': {
                    'source_id': 'sourceId',
                },
                'location_map': {
                    'source_id': 'path',
                    'delete_tag': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__delete_source_tags
        )

        def __get_source_by_id(
            self,
            source_id,
            **kwargs
        ):
            """Get a source by ID.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_source_by_id(source_id, async_req=True)
            >>> result = thread.get()

            Args:
                source_id (str): The ID of the Source.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                Source
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['source_id'] = \
                source_id
            return self.call_with_http_info(**kwargs)

        self.get_source_by_id = _Endpoint(
            settings={
                'response_type': (Source,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/sources/{sourceId}',
                'operation_id': 'get_source_by_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'source_id',
                ],
                'required': [
                    'source_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'source_id',
                ]
            },
            root_map={
                'validations': {
                    ('source_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'source_id':
                        (str,),
                },
                'attribute_map': {
                    'source_id': 'sourceId',
                },
                'location_map': {
                    'source_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_source_by_id
        )

        def __get_source_compatible_repo(
            self,
            source_id,
            **kwargs
        ):
            """Returns a list of repositories that match the specified source.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_source_compatible_repo(source_id, async_req=True)
            >>> result = thread.get()

            Args:
                source_id (str): The ID of the Source.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                StagingCompatibleEnvironmentsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['source_id'] = \
                source_id
            return self.call_with_http_info(**kwargs)

        self.get_source_compatible_repo = _Endpoint(
            settings={
                'response_type': (StagingCompatibleEnvironmentsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/sources/{sourceId}/staging_compatible_repositories',
                'operation_id': 'get_source_compatible_repo',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'source_id',
                ],
                'required': [
                    'source_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'source_id',
                ]
            },
            root_map={
                'validations': {
                    ('source_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'source_id':
                        (str,),
                },
                'attribute_map': {
                    'source_id': 'sourceId',
                },
                'location_map': {
                    'source_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_source_compatible_repo
        )

        def __get_source_tags(
            self,
            source_id,
            **kwargs
        ):
            """Get tags for a Source.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_source_tags(source_id, async_req=True)
            >>> result = thread.get()

            Args:
                source_id (str): The ID of the Source.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                TagsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['source_id'] = \
                source_id
            return self.call_with_http_info(**kwargs)

        self.get_source_tags = _Endpoint(
            settings={
                'response_type': (TagsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/sources/{sourceId}/tags',
                'operation_id': 'get_source_tags',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'source_id',
                ],
                'required': [
                    'source_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'source_id',
                ]
            },
            root_map={
                'validations': {
                    ('source_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'source_id':
                        (str,),
                },
                'attribute_map': {
                    'source_id': 'sourceId',
                },
                'location_map': {
                    'source_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_source_tags
        )

        def __get_sources(
            self,
            **kwargs
        ):
            """List all sources.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_sources(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies descending order.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListSourcesResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.get_sources = _Endpoint(
            settings={
                'response_type': (ListSourcesResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/sources',
                'operation_id': 'get_sources',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "DATABASE_TYPE": "database_type",
                        "-DATABASE_TYPE": "-database_type",
                        "NAME": "name",
                        "-NAME": "-name",
                        "DATABASE_VERSION": "database_version",
                        "-DATABASE_VERSION": "-database_version",
                        "ENVIRONMENT_ID": "environment_id",
                        "-ENVIRONMENT_ID": "-environment_id",
                        "DATA_UUID": "data_uuid",
                        "-DATA_UUID": "-data_uuid",
                        "IP_ADDRESS": "ip_address",
                        "-IP_ADDRESS": "-ip_address",
                        "FQDN": "fqdn",
                        "-FQDN": "-fqdn",
                        "SIZE": "size",
                        "-SIZE": "-size",
                        "JDBC_CONNECTION_STRING": "jdbc_connection_string",
                        "-JDBC_CONNECTION_STRING": "-jdbc_connection_string",
                        "PLUGIN_VERSION": "plugin_version",
                        "-PLUGIN_VERSION": "-plugin_version",
                        "IS_DSOURCE": "is_dsource",
                        "-IS_DSOURCE": "-is_dsource",
                        "INSTANCE_NAME": "instance_name",
                        "-INSTANCE_NAME": "-instance_name",
                        "INSTANCE_NUMBER": "instance_number",
                        "-INSTANCE_NUMBER": "-instance_number",
                        "USER": "user",
                        "-USER": "-user",
                        "NON_SYS_USER": "non_sys_user",
                        "-NON_SYS_USER": "-non_sys_user",
                        "DISCOVERED": "discovered",
                        "-DISCOVERED": "-discovered",
                        "LINKING_ENABLED": "linking_enabled",
                        "-LINKING_ENABLED": "-linking_enabled",
                        "REPOSITORY": "repository",
                        "-REPOSITORY": "-repository",
                        "CDB_TYPE": "cdb_type",
                        "-CDB_TYPE": "-cdb_type",
                        "ENVIRONMENT_USER_REF": "environment_user_ref",
                        "-ENVIRONMENT_USER_REF": "-environment_user_ref",
                        "DATA_CONNECTION_ID": "data_connection_id",
                        "-DATA_CONNECTION_ID": "-data_connection_id",
                        "DATABASE_NAME": "database_name",
                        "-DATABASE_NAME": "-database_name",
                        "DATABASE_UNIQUE_NAME": "database_unique_name",
                        "-DATABASE_UNIQUE_NAME": "-database_unique_name"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_sources
        )

        def __search_sources(
            self,
            **kwargs
        ):
            """Search for Sources.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.search_sources(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies descending order.. [optional]
                search_body (SearchBody): A request body containing a filter expression. This enables searching for items matching arbitrarily complex conditions. The list of attributes which can be used in filter expressions is available in the x-filterable vendor extension.  # Filter Expression Overview **Note: All keywords are case-insensitive**  ## Comparison Operators | Operator | Description | Example | | --- | --- | --- | | CONTAINS | Substring or membership testing for string and list attributes respectively. | field3 CONTAINS 'foobar', field4 CONTAINS TRUE  | | IN | Tests if field is a member of a list literal. List can contain a maximum of 100 values | field2 IN ['Goku', 'Vegeta'] | | GE | Tests if a field is greater than or equal to a literal value | field1 GE 1.2e-2 | | GT | Tests if a field is greater than a literal value | field1 GT 1.2e-2 | | LE | Tests if a field is less than or equal to a literal value | field1 LE 9000 | | LT | Tests if a field is less than a literal value | field1 LT 9.02 | | NE | Tests if a field is not equal to a literal value | field1 NE 42 | | EQ | Tests if a field is equal to a literal value | field1 EQ 42 |  ## Search Operator The SEARCH operator filters for items which have any filterable attribute that contains the input string as a substring, comparison is done case-insensitively. This is not restricted to attributes with string values. Specifically `SEARCH '12'` would match an item with an attribute with an integer value of `123`.  ## Logical Operators Ordered by precedence. | Operator | Description | Example | | --- | --- | --- | | NOT | Logical NOT (Right associative) | NOT field1 LE 9000 | | AND | Logical AND (Left Associative) | field1 GT 9000 AND field2 EQ 'Goku' | | OR | Logical OR (Left Associative) | field1 GT 9000 OR field2 EQ 'Goku' |  ## Grouping Parenthesis `()` can be used to override operator precedence.  For example: NOT (field1 LT 1234 AND field2 CONTAINS 'foo')  ## Literal Values | Literal      | Description | Examples | | --- | --- | --- | | Nil | Represents the absence of a value | nil, Nil, nIl, NIL | | Boolean | true/false boolean | true, false, True, False, TRUE, FALSE | | Number | Signed integer and floating point numbers. Also supports scientific notation. | 0, 1, -1, 1.2, 0.35, 1.2e-2, -1.2e+2 | | String | Single or double quoted | \"foo\", \"bar\", \"foo bar\", 'foo', 'bar', 'foo bar' | | Datetime | Formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339) | 2018-04-27T18:39:26.397237+00:00 | | List | Comma-separated literals wrapped in square brackets | [0], [0, 1], ['foo', \"bar\"] |  ## Limitations - A maximum of 8 unique identifiers may be used inside a filter expression. . [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                SearchSourcesResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.search_sources = _Endpoint(
            settings={
                'response_type': (SearchSourcesResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/sources/search',
                'operation_id': 'search_sources',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                    'search_body',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "DATABASE_TYPE": "database_type",
                        "-DATABASE_TYPE": "-database_type",
                        "NAME": "name",
                        "-NAME": "-name",
                        "DATABASE_VERSION": "database_version",
                        "-DATABASE_VERSION": "-database_version",
                        "ENVIRONMENT_ID": "environment_id",
                        "-ENVIRONMENT_ID": "-environment_id",
                        "DATA_UUID": "data_uuid",
                        "-DATA_UUID": "-data_uuid",
                        "IP_ADDRESS": "ip_address",
                        "-IP_ADDRESS": "-ip_address",
                        "FQDN": "fqdn",
                        "-FQDN": "-fqdn",
                        "SIZE": "size",
                        "-SIZE": "-size",
                        "JDBC_CONNECTION_STRING": "jdbc_connection_string",
                        "-JDBC_CONNECTION_STRING": "-jdbc_connection_string",
                        "PLUGIN_VERSION": "plugin_version",
                        "-PLUGIN_VERSION": "-plugin_version",
                        "IS_DSOURCE": "is_dsource",
                        "-IS_DSOURCE": "-is_dsource",
                        "INSTANCE_NAME": "instance_name",
                        "-INSTANCE_NAME": "-instance_name",
                        "INSTANCE_NUMBER": "instance_number",
                        "-INSTANCE_NUMBER": "-instance_number",
                        "USER": "user",
                        "-USER": "-user",
                        "NON_SYS_USER": "non_sys_user",
                        "-NON_SYS_USER": "-non_sys_user",
                        "DISCOVERED": "discovered",
                        "-DISCOVERED": "-discovered",
                        "LINKING_ENABLED": "linking_enabled",
                        "-LINKING_ENABLED": "-linking_enabled",
                        "REPOSITORY": "repository",
                        "-REPOSITORY": "-repository",
                        "CDB_TYPE": "cdb_type",
                        "-CDB_TYPE": "-cdb_type",
                        "ENVIRONMENT_USER_REF": "environment_user_ref",
                        "-ENVIRONMENT_USER_REF": "-environment_user_ref",
                        "DATA_CONNECTION_ID": "data_connection_id",
                        "-DATA_CONNECTION_ID": "-data_connection_id",
                        "DATABASE_NAME": "database_name",
                        "-DATABASE_NAME": "-database_name",
                        "DATABASE_UNIQUE_NAME": "database_unique_name",
                        "-DATABASE_UNIQUE_NAME": "-database_unique_name"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                    'search_body':
                        (SearchBody,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                    'search_body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__search_sources
        )

        def __update_appdata_source_by_id(
            self,
            source_id,
            app_data_source_update_parameters,
            **kwargs
        ):
            """Update a AppData source by ID.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.update_appdata_source_by_id(source_id, app_data_source_update_parameters, async_req=True)
            >>> result = thread.get()

            Args:
                source_id (str): The ID of the Source.
                app_data_source_update_parameters (AppDataSourceUpdateParameters): The parameters to update an AppData source.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                UpdateAppDataSourceResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['source_id'] = \
                source_id
            kwargs['app_data_source_update_parameters'] = \
                app_data_source_update_parameters
            return self.call_with_http_info(**kwargs)

        self.update_appdata_source_by_id = _Endpoint(
            settings={
                'response_type': (UpdateAppDataSourceResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/sources/appdata/{sourceId}',
                'operation_id': 'update_appdata_source_by_id',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'source_id',
                    'app_data_source_update_parameters',
                ],
                'required': [
                    'source_id',
                    'app_data_source_update_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'source_id',
                ]
            },
            root_map={
                'validations': {
                    ('source_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'source_id':
                        (str,),
                    'app_data_source_update_parameters':
                        (AppDataSourceUpdateParameters,),
                },
                'attribute_map': {
                    'source_id': 'sourceId',
                },
                'location_map': {
                    'source_id': 'path',
                    'app_data_source_update_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__update_appdata_source_by_id
        )

        def __update_ase_source_by_id(
            self,
            source_id,
            ase_source_update_parameters,
            **kwargs
        ):
            """Update an ASE source by ID.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.update_ase_source_by_id(source_id, ase_source_update_parameters, async_req=True)
            >>> result = thread.get()

            Args:
                source_id (str): The ID of the Source.
                ase_source_update_parameters (AseSourceUpdateParameters): The parameters to update an ASE source.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                UpdateAseSourceResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['source_id'] = \
                source_id
            kwargs['ase_source_update_parameters'] = \
                ase_source_update_parameters
            return self.call_with_http_info(**kwargs)

        self.update_ase_source_by_id = _Endpoint(
            settings={
                'response_type': (UpdateAseSourceResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/sources/ase/{sourceId}',
                'operation_id': 'update_ase_source_by_id',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'source_id',
                    'ase_source_update_parameters',
                ],
                'required': [
                    'source_id',
                    'ase_source_update_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'source_id',
                ]
            },
            root_map={
                'validations': {
                    ('source_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'source_id':
                        (str,),
                    'ase_source_update_parameters':
                        (AseSourceUpdateParameters,),
                },
                'attribute_map': {
                    'source_id': 'sourceId',
                },
                'location_map': {
                    'source_id': 'path',
                    'ase_source_update_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__update_ase_source_by_id
        )

        def __update_oracle_source_by_id(
            self,
            source_id,
            **kwargs
        ):
            """Update an Oracle source by ID.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.update_oracle_source_by_id(source_id, async_req=True)
            >>> result = thread.get()

            Args:
                source_id (str): The ID of the Source.

            Keyword Args:
                oracle_source_update_parameters (OracleSourceUpdateParameters): The parameters to update a Oracle source. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                UpdateOracleSourceResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['source_id'] = \
                source_id
            return self.call_with_http_info(**kwargs)

        self.update_oracle_source_by_id = _Endpoint(
            settings={
                'response_type': (UpdateOracleSourceResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/sources/oracle/{sourceId}',
                'operation_id': 'update_oracle_source_by_id',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'source_id',
                    'oracle_source_update_parameters',
                ],
                'required': [
                    'source_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'source_id',
                ]
            },
            root_map={
                'validations': {
                    ('source_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'source_id':
                        (str,),
                    'oracle_source_update_parameters':
                        (OracleSourceUpdateParameters,),
                },
                'attribute_map': {
                    'source_id': 'sourceId',
                },
                'location_map': {
                    'source_id': 'path',
                    'oracle_source_update_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__update_oracle_source_by_id
        )

        def __update_postgres_source_by_id(
            self,
            source_id,
            **kwargs
        ):
            """Update a PostgreSQL source by ID.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.update_postgres_source_by_id(source_id, async_req=True)
            >>> result = thread.get()

            Args:
                source_id (str): The ID of the Source.

            Keyword Args:
                postgres_source_update_parameters (PostgresSourceUpdateParameters): The parameters to update a PostgreSQL source. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                UpdatePostgresSourceResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['source_id'] = \
                source_id
            return self.call_with_http_info(**kwargs)

        self.update_postgres_source_by_id = _Endpoint(
            settings={
                'response_type': (UpdatePostgresSourceResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/sources/postgres/{sourceId}',
                'operation_id': 'update_postgres_source_by_id',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'source_id',
                    'postgres_source_update_parameters',
                ],
                'required': [
                    'source_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'source_id',
                ]
            },
            root_map={
                'validations': {
                    ('source_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'source_id':
                        (str,),
                    'postgres_source_update_parameters':
                        (PostgresSourceUpdateParameters,),
                },
                'attribute_map': {
                    'source_id': 'sourceId',
                },
                'location_map': {
                    'source_id': 'path',
                    'postgres_source_update_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__update_postgres_source_by_id
        )

        def __update_source_by_id(
            self,
            source_id,
            **kwargs
        ):
            """Update a Source.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.update_source_by_id(source_id, async_req=True)
            >>> result = thread.get()

            Args:
                source_id (str): The ID of the Source.

            Keyword Args:
                update_source_parameters (UpdateSourceParameters): The parameters to update a Source.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                UpdateSourceResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['source_id'] = \
                source_id
            return self.call_with_http_info(**kwargs)

        self.update_source_by_id = _Endpoint(
            settings={
                'response_type': (UpdateSourceResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/sources/{sourceId}/update',
                'operation_id': 'update_source_by_id',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'source_id',
                    'update_source_parameters',
                ],
                'required': [
                    'source_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'source_id',
                ]
            },
            root_map={
                'validations': {
                    ('source_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'source_id':
                        (str,),
                    'update_source_parameters':
                        (UpdateSourceParameters,),
                },
                'attribute_map': {
                    'source_id': 'sourceId',
                },
                'location_map': {
                    'source_id': 'path',
                    'update_source_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__update_source_by_id
        )

        def __verify_source_jdbc_connection_string(
            self,
            source_id,
            **kwargs
        ):
            """Verify JDBC connection string for a source.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.verify_source_jdbc_connection_string(source_id, async_req=True)
            >>> result = thread.get()

            Args:
                source_id (str): The ID of the Source.

            Keyword Args:
                oracle_verify_jdbc_connection_string_params (OracleVerifyJdbcConnectionStringParams): The parameters to verify oracle jdbc connection string.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ConnectivityCheckResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['source_id'] = \
                source_id
            return self.call_with_http_info(**kwargs)

        self.verify_source_jdbc_connection_string = _Endpoint(
            settings={
                'response_type': (ConnectivityCheckResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/sources/{sourceId}/jdbc-check',
                'operation_id': 'verify_source_jdbc_connection_string',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'source_id',
                    'oracle_verify_jdbc_connection_string_params',
                ],
                'required': [
                    'source_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'source_id',
                ]
            },
            root_map={
                'validations': {
                    ('source_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'source_id':
                        (str,),
                    'oracle_verify_jdbc_connection_string_params':
                        (OracleVerifyJdbcConnectionStringParams,),
                },
                'attribute_map': {
                    'source_id': 'sourceId',
                },
                'location_map': {
                    'source_id': 'path',
                    'oracle_verify_jdbc_connection_string_params': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__verify_source_jdbc_connection_string
        )



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.masking_jobs_api import MaskingJobsApi  # noqa: E501


class TestMaskingJobsApi(unittest.TestCase):
    """MaskingJobsApi unit test stubs"""

    def setUp(self):
        self.api = MaskingJobsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_engine_to_masking_job(self):
        """Test case for add_engine_to_masking_job

        Add an engine to a Masking Job (Hyperscale Job only).  # noqa: E501
        """
        pass

    def test_copy_masking_job(self):
        """Test case for copy_masking_job

        Copies the masking job to another engine.  # noqa: E501
        """
        pass

    def test_create_masking_job(self):
        """Test case for create_masking_job

        Create a Masking Job.  # noqa: E501
        """
        pass

    def test_create_masking_job_tag(self):
        """Test case for create_masking_job_tag

        Create tags for a Masking Job.  # noqa: E501
        """
        pass

    def test_delete_masking_job(self):
        """Test case for delete_masking_job

        Delete a masking job.  # noqa: E501
        """
        pass

    def test_delete_masking_job_tag(self):
        """Test case for delete_masking_job_tag

        Delete tags for a Masking Job.  # noqa: E501
        """
        pass

    def test_execute_masking_job(self):
        """Test case for execute_masking_job

        Execute a MaskingJob.  # noqa: E501
        """
        pass

    def test_get_masking_job_by_id(self):
        """Test case for get_masking_job_by_id

        Retrieve a MaskingJob by ID.  # noqa: E501
        """
        pass

    def test_get_masking_job_connectors(self):
        """Test case for get_masking_job_connectors

        Get connectors for a Masking Job by ID.  # noqa: E501
        """
        pass

    def test_get_masking_job_source_engines(self):
        """Test case for get_masking_job_source_engines

        Retrieve the list of masking jobs along with their source engine.  # noqa: E501
        """
        pass

    def test_get_masking_job_tag(self):
        """Test case for get_masking_job_tag

        Get tags for a Masking Job.  # noqa: E501
        """
        pass

    def test_get_masking_jobs(self):
        """Test case for get_masking_jobs

        Retrieve the list of masking jobs.  # noqa: E501
        """
        pass

    def test_migrate_masking_job(self):
        """Test case for migrate_masking_job

        Migrates the masking job from its current source engine to another engine.  # noqa: E501
        """
        pass

    def test_re_import_masking_job(self):
        """Test case for re_import_masking_job

        Re-import the dataset from the source MaskingJob (Hyperscale Job only).  # noqa: E501
        """
        pass

    def test_remove_engine_from_masking_job(self):
        """Test case for remove_engine_from_masking_job

        Remove an engine from a Masking Job (Hyperscale Job only).  # noqa: E501
        """
        pass

    def test_search_masking_job_source_engines(self):
        """Test case for search_masking_job_source_engines

        Search the list of masking jobs along with their source engine.  # noqa: E501
        """
        pass

    def test_search_masking_jobs(self):
        """Test case for search_masking_jobs

        Search masking jobs.  # noqa: E501
        """
        pass

    def test_update_masking_job_by_id(self):
        """Test case for update_masking_job_by_id

        Update values of a MaskingJob.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.storage_summary_historical_data_point import StorageSummaryHistoricalDataPoint
from delphix.api.gateway.model.storage_summary_projected_data_point import StorageSummaryProjectedDataPoint
globals()['StorageSummaryHistoricalDataPoint'] = StorageSummaryHistoricalDataPoint
globals()['StorageSummaryProjectedDataPoint'] = StorageSummaryProjectedDataPoint
from delphix.api.gateway.model.historical_storage_summary_aggregate import HistoricalStorageSummaryAggregate


class TestHistoricalStorageSummaryAggregate(unittest.TestCase):
    """HistoricalStorageSummaryAggregate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testHistoricalStorageSummaryAggregate(self):
        """Test HistoricalStorageSummaryAggregate"""
        # FIXME: construct object with mandatory attributes with example values
        # model = HistoricalStorageSummaryAggregate()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.database_templates_api import DatabaseTemplatesApi  # noqa: E501


class TestDatabaseTemplatesApi(unittest.TestCase):
    """DatabaseTemplatesApi unit test stubs"""

    def setUp(self):
        self.api = DatabaseTemplatesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_database_template(self):
        """Test case for create_database_template

        Create a database template.  # noqa: E501
        """
        pass

    def test_create_database_template_tags(self):
        """Test case for create_database_template_tags

        Create tags for a DatabaseTemplate.  # noqa: E501
        """
        pass

    def test_delete_database_template(self):
        """Test case for delete_database_template

        Delete a DatabaseTemplate by ID.  # noqa: E501
        """
        pass

    def test_delete_database_template_tag(self):
        """Test case for delete_database_template_tag

        Delete tags for a DatabaseTemplate.  # noqa: E501
        """
        pass

    def test_get_database_template_by_id(self):
        """Test case for get_database_template_by_id

        Retrieve a DatabaseTemplate by ID.  # noqa: E501
        """
        pass

    def test_get_database_template_tags(self):
        """Test case for get_database_template_tags

        Get tags for a DatabaseTemplate.  # noqa: E501
        """
        pass

    def test_get_database_templates(self):
        """Test case for get_database_templates

        Retrieve the list of database templates.  # noqa: E501
        """
        pass

    def test_import_database_templates(self):
        """Test case for import_database_templates

        Imports the database templates from an engine.  # noqa: E501
        """
        pass

    def test_search_database_templates(self):
        """Test case for search_database_templates

        Search DatabaseTemplates.  # noqa: E501
        """
        pass

    def test_undo_import_database_templates(self):
        """Test case for undo_import_database_templates

        Undo an import of DatabaseTemplates on an Engine.  # noqa: E501
        """
        pass

    def test_update_database_template(self):
        """Test case for update_database_template

        Updates a DatabaseTemplate by ID  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.masking_files_api import MaskingFilesApi  # noqa: E501


class TestMaskingFilesApi(unittest.TestCase):
    """MaskingFilesApi unit test stubs"""

    def setUp(self):
        self.api = MaskingFilesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_masking_file_tags(self):
        """Test case for create_masking_file_tags

        Create tags for a masking file.  # noqa: E501
        """
        pass

    def test_delete_masking_file_tags(self):
        """Test case for delete_masking_file_tags

        Delete tags for a masking file  # noqa: E501
        """
        pass

    def test_get_masking_file_by_id(self):
        """Test case for get_masking_file_by_id

        Get a masking file by ID or name.  # noqa: E501
        """
        pass

    def test_get_masking_file_consumers(self):
        """Test case for get_masking_file_consumers

        Get all consumers associated with this masking file  # noqa: E501
        """
        pass

    def test_get_masking_file_tags(self):
        """Test case for get_masking_file_tags

        Get tags for a masking file.  # noqa: E501
        """
        pass

    def test_get_masking_files(self):
        """Test case for get_masking_files

        Retrieve the list of masking file uploads.  # noqa: E501
        """
        pass

    def test_search_masking_file_consumers(self):
        """Test case for search_masking_file_consumers

        Search consumers of a masking file.  # noqa: E501
        """
        pass

    def test_search_masking_files(self):
        """Test case for search_masking_files

        Search for masking files.  # noqa: E501
        """
        pass

    def test_update_masking_file_upload_by_id(self):
        """Test case for update_masking_file_upload_by_id

        Update a masking file upload by id.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.discovery_expressions_api import DiscoveryExpressionsApi  # noqa: E501


class TestDiscoveryExpressionsApi(unittest.TestCase):
    """DiscoveryExpressionsApi unit test stubs"""

    def setUp(self):
        self.api = DiscoveryExpressionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_discovery_expression_tags(self):
        """Test case for create_discovery_expression_tags

        Create tags for a discovery expression.  # noqa: E501
        """
        pass

    def test_delete_discovery_expression_tags(self):
        """Test case for delete_discovery_expression_tags

        Delete tags for a discovery expression.  # noqa: E501
        """
        pass

    def test_get_discovery_expression_by_id(self):
        """Test case for get_discovery_expression_by_id

        Get a discovery expression by ID.  # noqa: E501
        """
        pass

    def test_get_discovery_expression_tags(self):
        """Test case for get_discovery_expression_tags

        Get tags for a discovery expression.  # noqa: E501
        """
        pass

    def test_get_discovery_expressions(self):
        """Test case for get_discovery_expressions

        Retrieve discovery expressions.  # noqa: E501
        """
        pass

    def test_search_discovery_expressions(self):
        """Test case for search_discovery_expressions

        Search discovery expressions.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.base_export_transfer_strategy_parameters import BaseExportTransferStrategyParameters
from delphix.api.gateway.model.in_place_export_parameters_all_of import InPlaceExportParametersAllOf
from delphix.api.gateway.model.oracle_asm_layout_parameters import OracleAsmLayoutParameters
globals()['BaseExportTransferStrategyParameters'] = BaseExportTransferStrategyParameters
globals()['InPlaceExportParametersAllOf'] = InPlaceExportParametersAllOf
globals()['OracleAsmLayoutParameters'] = OracleAsmLayoutParameters
from delphix.api.gateway.model.oracle_asm_in_place_export_parameters import OracleAsmInPlaceExportParameters


class TestOracleAsmInPlaceExportParameters(unittest.TestCase):
    """OracleAsmInPlaceExportParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testOracleAsmInPlaceExportParameters(self):
        """Test OracleAsmInPlaceExportParameters"""
        # FIXME: construct object with mandatory attributes with example values
        # model = OracleAsmInPlaceExportParameters()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.storage_usage_api import StorageUsageApi  # noqa: E501


class TestStorageUsageApi(unittest.TestCase):
    """StorageUsageApi unit test stubs"""

    def setUp(self):
        self.api = StorageUsageApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_historical_storage_summary_aggregate(self):
        """Test case for get_historical_storage_summary_aggregate

        Returns the aggregated historical storage usage of all registered engines over time, optionally with a projection of future storage usage.  # noqa: E501
        """
        pass

    def test_get_historical_storage_summary_by_engine(self):
        """Test case for get_historical_storage_summary_by_engine

        Returns the historical storage usage by engine over time, optionally with a projection of future storage usage.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.virtualization_jobs_api import VirtualizationJobsApi  # noqa: E501


class TestVirtualizationJobsApi(unittest.TestCase):
    """VirtualizationJobsApi unit test stubs"""

    def setUp(self):
        self.api = VirtualizationJobsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_virtualization_job_history(self):
        """Test case for get_virtualization_job_history

        Fetch a list of all virtualization jobs  # noqa: E501
        """
        pass

    def test_search_virtualization_job_history(self):
        """Test case for search_virtualization_job_history

        Search virtualization jobs  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.latency_test_request import LatencyTestRequest
from delphix.api.gateway.model.network_latency_test_result_all_of import NetworkLatencyTestResultAllOf
from delphix.api.gateway.model.network_test_base_result import NetworkTestBaseResult
globals()['LatencyTestRequest'] = LatencyTestRequest
globals()['NetworkLatencyTestResultAllOf'] = NetworkLatencyTestResultAllOf
globals()['NetworkTestBaseResult'] = NetworkTestBaseResult
from delphix.api.gateway.model.network_latency_test_result import NetworkLatencyTestResult


class TestNetworkLatencyTestResult(unittest.TestCase):
    """NetworkLatencyTestResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNetworkLatencyTestResult(self):
        """Test NetworkLatencyTestResult"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NetworkLatencyTestResult()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from delphix.api.gateway.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
)
from ..model_utils import OpenApiModel
from delphix.api.gateway.exceptions import ApiAttributeError


def lazy_import():
    from delphix.api.gateway.model.base_export_transfer_strategy_parameters import BaseExportTransferStrategyParameters
    from delphix.api.gateway.model.export_db_timeflow_point_parameters import ExportDBTimeflowPointParameters
    from delphix.api.gateway.model.oracle_asm_export_by_location_parameters_all_of import OracleAsmExportByLocationParametersAllOf
    from delphix.api.gateway.model.oracle_asm_layout_parameters import OracleAsmLayoutParameters
    from delphix.api.gateway.model.oracle_rac_database_instance import OracleRACDatabaseInstance
    from delphix.api.gateway.model.oracle_tde_keystore_config_type_enum import OracleTdeKeystoreConfigTypeEnum
    globals()['BaseExportTransferStrategyParameters'] = BaseExportTransferStrategyParameters
    globals()['ExportDBTimeflowPointParameters'] = ExportDBTimeflowPointParameters
    globals()['OracleAsmExportByLocationParametersAllOf'] = OracleAsmExportByLocationParametersAllOf
    globals()['OracleAsmLayoutParameters'] = OracleAsmLayoutParameters
    globals()['OracleRACDatabaseInstance'] = OracleRACDatabaseInstance
    globals()['OracleTdeKeystoreConfigTypeEnum'] = OracleTdeKeystoreConfigTypeEnum


class OracleAsmExportByLocationParameters(ModelComposed):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
        ('recovery_model',): {
            'FULL': "FULL",
            'SIMPLE': "SIMPLE",
            'BULK_LOGGED': "BULK_LOGGED",
        },
        ('mirroring_state',): {
            'SUSPENDED': "SUSPENDED",
            'DISCONNECTED': "DISCONNECTED",
            'SYNCHRONIZING': "SYNCHRONIZING",
            'PENDING_FAILOVER': "PENDING_FAILOVER",
            'SYNCHRONIZED': "SYNCHRONIZED",
            'NOT_SYNCHRONIZED': "NOT_SYNCHRONIZED",
            'FAILOVER_POSSIBLE': "FAILOVER_POSSIBLE",
            'NONE': "NONE",
        },
    }

    validations = {
        ('location',): {
            'max_length': 256,
            'min_length': 1,
        },
        ('oracle_instance_name',): {
            'max_length': 15,
            'min_length': 1,
            'regex': {
                'pattern': r'^[a-zA-Z0-9_]+$',  # noqa: E501
            },
        },
        ('rman_channels',): {
            'inclusive_maximum': 32,
            'inclusive_minimum': 1,
        },
    }

    @cached_property
    def additional_properties_type():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded
        """
        lazy_import()
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'default_data_diskgroup': (str,),  # noqa: E501
            'location': (str,),  # noqa: E501
            'unique_name': (str,),  # noqa: E501
            'database_name': (str,),  # noqa: E501
            'repository_id': (str,),  # noqa: E501
            'environment_user_ref': (str,),  # noqa: E501
            'tde_keystore_password': (str,),  # noqa: E501
            'tde_keystore_config_type': (OracleTdeKeystoreConfigTypeEnum,),  # noqa: E501
            'oracle_instance_name': (str,),  # noqa: E501
            'instance_number': (int,),  # noqa: E501
            'instances': ([OracleRACDatabaseInstance],),  # noqa: E501
            'mount_base': (str,),  # noqa: E501
            'config_params': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type,),  # noqa: E501
            'cdb_id': (str,),  # noqa: E501
            'parent_tde_keystore_path': (str,),  # noqa: E501
            'parent_tde_keystore_password': (str,),  # noqa: E501
            'tde_exported_keyfile_secret': (str,),  # noqa: E501
            'tde_key_identifier': (str,),  # noqa: E501
            'crs_database_name': (str,),  # noqa: E501
            'recover_database': (bool,),  # noqa: E501
            'file_mapping_rules': (str,),  # noqa: E501
            'enable_cdc': (bool,),  # noqa: E501
            'recovery_model': (str,),  # noqa: E501
            'mirroring_state': (str,),  # noqa: E501
            'redo_diskgroup': (str,),  # noqa: E501
            'rman_channels': (int,),  # noqa: E501
            'rman_file_section_size_in_gb': (int,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'default_data_diskgroup': 'default_data_diskgroup',  # noqa: E501
        'location': 'location',  # noqa: E501
        'unique_name': 'unique_name',  # noqa: E501
        'database_name': 'database_name',  # noqa: E501
        'repository_id': 'repository_id',  # noqa: E501
        'environment_user_ref': 'environment_user_ref',  # noqa: E501
        'tde_keystore_password': 'tde_keystore_password',  # noqa: E501
        'tde_keystore_config_type': 'tde_keystore_config_type',  # noqa: E501
        'oracle_instance_name': 'oracle_instance_name',  # noqa: E501
        'instance_number': 'instance_number',  # noqa: E501
        'instances': 'instances',  # noqa: E501
        'mount_base': 'mount_base',  # noqa: E501
        'config_params': 'config_params',  # noqa: E501
        'cdb_id': 'cdb_id',  # noqa: E501
        'parent_tde_keystore_path': 'parent_tde_keystore_path',  # noqa: E501
        'parent_tde_keystore_password': 'parent_tde_keystore_password',  # noqa: E501
        'tde_exported_keyfile_secret': 'tde_exported_keyfile_secret',  # noqa: E501
        'tde_key_identifier': 'tde_key_identifier',  # noqa: E501
        'crs_database_name': 'crs_database_name',  # noqa: E501
        'recover_database': 'recover_database',  # noqa: E501
        'file_mapping_rules': 'file_mapping_rules',  # noqa: E501
        'enable_cdc': 'enable_cdc',  # noqa: E501
        'recovery_model': 'recovery_model',  # noqa: E501
        'mirroring_state': 'mirroring_state',  # noqa: E501
        'redo_diskgroup': 'redo_diskgroup',  # noqa: E501
        'rman_channels': 'rman_channels',  # noqa: E501
        'rman_file_section_size_in_gb': 'rman_file_section_size_in_gb',  # noqa: E501
    }

    read_only_vars = {
    }

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, *args, **kwargs):  # noqa: E501
        """OracleAsmExportByLocationParameters - a model defined in OpenAPI

        Keyword Args:
            default_data_diskgroup (str): Default diskgroup for datafiles.
            location (str): The SCN value in the snapshot to perform the export from this SCN location.
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            unique_name (str): The unique name of the database.. [optional]  # noqa: E501
            database_name (str): The name of the database.. [optional]  # noqa: E501
            repository_id (str): The repository_id to use for this operation.. [optional]  # noqa: E501
            environment_user_ref (str): The environment user reference.. [optional]  # noqa: E501
            tde_keystore_password (str): The password for the Transparent Data Encryption keystore associated with this database.. [optional]  # noqa: E501
            tde_keystore_config_type (OracleTdeKeystoreConfigTypeEnum): [optional]  # noqa: E501
            oracle_instance_name (str): SID of the exported database. [optional]  # noqa: E501
            instance_number (int): The number of the instance.. [optional]  # noqa: E501
            instances ([OracleRACDatabaseInstance]): [optional]  # noqa: E501
            mount_base (str): The base mount point to use for the NFS mounts for the temporary VDB.. [optional]  # noqa: E501
            config_params ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type): Database configuration parameter overrides.. [optional]  # noqa: E501
            cdb_id (str): ID of an Oracle multitenant database this pluggable database belongs to.. [optional]  # noqa: E501
            parent_tde_keystore_path (str): Path to a copy of the parent's Oracle transparent data encryption keystore on the target host.. [optional]  # noqa: E501
            parent_tde_keystore_password (str): The password of the keystore specified in parentTdeKeystorePath.. [optional]  # noqa: E501
            tde_exported_keyfile_secret (str): Secret to be used while exporting and importing vPDB encryption keys.. [optional]  # noqa: E501
            tde_key_identifier (str): Virtual database master encryption key id, as recorded in v$encryption_keys.key_id.. [optional]  # noqa: E501
            crs_database_name (str): The Oracle Clusterware database name.. [optional]  # noqa: E501
            recover_database (bool): If specified, then take the exported database through recovery procedures, if necessary, to reach a consistent point.. [optional] if omitted the server will use the default value of True  # noqa: E501
            file_mapping_rules (str): Database file mapping rules.. [optional]  # noqa: E501
            enable_cdc (bool): Indicates whether to enable Change Data Capture (CDC) or not on exported database(MSSql Only).. [optional] if omitted the server will use the default value of False  # noqa: E501
            recovery_model (str): Recovery model of the database (MSSql Only).. [optional] if omitted the server will use the default value of "FULL"  # noqa: E501
            mirroring_state (str): Recovery model of the database (MSSql Only).. [optional] if omitted the server will use the default value of "NONE"  # noqa: E501
            redo_diskgroup (str): Diskgroup for archive logs. Optional as it is not required for PDB databases.. [optional]  # noqa: E501
            rman_channels (int): Number of data streams to connect to the database.. [optional] if omitted the server will use the default value of 8  # noqa: E501
            rman_file_section_size_in_gb (int): Number of GigaBytes in which RMAN will break large files to back them in parallel.. [optional] if omitted the server will use the default value of 0  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(OpenApiModel, cls).__new__(cls)

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        constant_args = {
            '_check_type': _check_type,
            '_path_to_item': _path_to_item,
            '_spec_property_naming': _spec_property_naming,
            '_configuration': _configuration,
            '_visited_composed_classes': self._visited_composed_classes,
        }
        composed_info = validate_get_composed_info(
            constant_args, kwargs, self)
        self._composed_instances = composed_info[0]
        self._var_name_to_model_instances = composed_info[1]
        self._additional_properties_model_instances = composed_info[2]
        discarded_args = composed_info[3]

        for var_name, var_value in kwargs.items():
            if var_name in discarded_args and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self._additional_properties_model_instances:
                # discard variable.
                continue
            setattr(self, var_name, var_value)

        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
        '_composed_instances',
        '_var_name_to_model_instances',
        '_additional_properties_model_instances',
    ])

    @convert_js_args_to_python_args
    def __init__(self, *args, **kwargs):  # noqa: E501
        """OracleAsmExportByLocationParameters - a model defined in OpenAPI

        Keyword Args:
            default_data_diskgroup (str): Default diskgroup for datafiles.
            location (str): The SCN value in the snapshot to perform the export from this SCN location.
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            unique_name (str): The unique name of the database.. [optional]  # noqa: E501
            database_name (str): The name of the database.. [optional]  # noqa: E501
            repository_id (str): The repository_id to use for this operation.. [optional]  # noqa: E501
            environment_user_ref (str): The environment user reference.. [optional]  # noqa: E501
            tde_keystore_password (str): The password for the Transparent Data Encryption keystore associated with this database.. [optional]  # noqa: E501
            tde_keystore_config_type (OracleTdeKeystoreConfigTypeEnum): [optional]  # noqa: E501
            oracle_instance_name (str): SID of the exported database. [optional]  # noqa: E501
            instance_number (int): The number of the instance.. [optional]  # noqa: E501
            instances ([OracleRACDatabaseInstance]): [optional]  # noqa: E501
            mount_base (str): The base mount point to use for the NFS mounts for the temporary VDB.. [optional]  # noqa: E501
            config_params ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type): Database configuration parameter overrides.. [optional]  # noqa: E501
            cdb_id (str): ID of an Oracle multitenant database this pluggable database belongs to.. [optional]  # noqa: E501
            parent_tde_keystore_path (str): Path to a copy of the parent's Oracle transparent data encryption keystore on the target host.. [optional]  # noqa: E501
            parent_tde_keystore_password (str): The password of the keystore specified in parentTdeKeystorePath.. [optional]  # noqa: E501
            tde_exported_keyfile_secret (str): Secret to be used while exporting and importing vPDB encryption keys.. [optional]  # noqa: E501
            tde_key_identifier (str): Virtual database master encryption key id, as recorded in v$encryption_keys.key_id.. [optional]  # noqa: E501
            crs_database_name (str): The Oracle Clusterware database name.. [optional]  # noqa: E501
            recover_database (bool): If specified, then take the exported database through recovery procedures, if necessary, to reach a consistent point.. [optional] if omitted the server will use the default value of True  # noqa: E501
            file_mapping_rules (str): Database file mapping rules.. [optional]  # noqa: E501
            enable_cdc (bool): Indicates whether to enable Change Data Capture (CDC) or not on exported database(MSSql Only).. [optional] if omitted the server will use the default value of False  # noqa: E501
            recovery_model (str): Recovery model of the database (MSSql Only).. [optional] if omitted the server will use the default value of "FULL"  # noqa: E501
            mirroring_state (str): Recovery model of the database (MSSql Only).. [optional] if omitted the server will use the default value of "NONE"  # noqa: E501
            redo_diskgroup (str): Diskgroup for archive logs. Optional as it is not required for PDB databases.. [optional]  # noqa: E501
            rman_channels (int): Number of data streams to connect to the database.. [optional] if omitted the server will use the default value of 8  # noqa: E501
            rman_file_section_size_in_gb (int): Number of GigaBytes in which RMAN will break large files to back them in parallel.. [optional] if omitted the server will use the default value of 0  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        constant_args = {
            '_check_type': _check_type,
            '_path_to_item': _path_to_item,
            '_spec_property_naming': _spec_property_naming,
            '_configuration': _configuration,
            '_visited_composed_classes': self._visited_composed_classes,
        }
        composed_info = validate_get_composed_info(
            constant_args, kwargs, self)
        self._composed_instances = composed_info[0]
        self._var_name_to_model_instances = composed_info[1]
        self._additional_properties_model_instances = composed_info[2]
        discarded_args = composed_info[3]

        for var_name, var_value in kwargs.items():
            if var_name in discarded_args and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self._additional_properties_model_instances:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_openapi_data` to instantiate "
                                     f"class with read only attributes.")

    @cached_property
    def _composed_schemas():
        # we need this here to make our import statements work
        # we must store _composed_schemas in here so the code is only run
        # when we invoke this method. If we kept this at the class
        # level we would get an error beause the class level
        # code would be run when this module is imported, and these composed
        # classes don't exist yet because their module has not finished
        # loading
        lazy_import()
        return {
          'anyOf': [
          ],
          'allOf': [
              BaseExportTransferStrategyParameters,
              ExportDBTimeflowPointParameters,
              OracleAsmExportByLocationParametersAllOf,
              OracleAsmLayoutParameters,
          ],
          'oneOf': [
          ],
        }



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.24.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.classifiers_api import ClassifiersApi  # noqa: E501


class TestClassifiersApi(unittest.TestCase):
    """ClassifiersApi unit test stubs"""

    def setUp(self):
        self.api = ClassifiersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_classifier_tags(self):
        """Test case for create_classifier_tags

        Create tags for a classifier.  # noqa: E501
        """
        pass

    def test_delete_classifier_tags(self):
        """Test case for delete_classifier_tags

        Delete tags for a classifier.  # noqa: E501
        """
        pass

    def test_get_classifier_by_id(self):
        """Test case for get_classifier_by_id

        Get a classifier by ID.  # noqa: E501
        """
        pass

    def test_get_classifier_discovery_policies(self):
        """Test case for get_classifier_discovery_policies

        Get discovery policies for a classifier.  # noqa: E501
        """
        pass

    def test_get_classifier_tags(self):
        """Test case for get_classifier_tags

        Get tags for a classifier.  # noqa: E501
        """
        pass

    def test_get_classifiers(self):
        """Test case for get_classifiers

        Retrieve classifiers.  # noqa: E501
        """
        pass

    def test_search_classifier_discovery_policies(self):
        """Test case for search_classifier_discovery_policies

        Search discovery policies for a classifier.  # noqa: E501
        """
        pass

    def test_search_classifiers(self):
        """Test case for search_classifiers

        Search for classifiers.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
